==> stylelint-12.0.1.tgz: package/lib/rules/declaration-block-semicolon-space-before/index.js <==
'use strict';

const blockString = require('../../utils/blockString');
const report = require('../../utils/report');
const ruleMessages = require('../../utils/ruleMessages');
const validateOptions = require('../../utils/validateOptions');
const whitespaceChecker = require('../../utils/whitespaceChecker');

const ruleName = 'declaration-block-semicolon-space-before';

const messages = ruleMessages(ruleName, {
	expectedBefore: () => 'Expected single space before ";"',
	rejectedBefore: () => 'Unexpected whitespace before ";"',
	expectedBeforeSingleLine: () =>
		'Expected single space before ";" in a single-line declaration block',
	rejectedBeforeSingleLine: () =>
		'Unexpected whitespace before ";" in a single-line declaration block',
});

const rule = function(expectation, options, context) {
	const checker = whitespaceChecker('space', expectation, messages);

	return (root, result) => {
		const validOptions = validateOptions(result, ruleName, {
			actual: expectation,
			possible: ['always', 'never', 'always-single-line', 'never-single-line'],
		});

		if (!validOptions) {
			return;
		}

		root.walkDecls((decl) => {
			// Ignore last declaration if there's no trailing semicolon
			const parentRule = decl.parent;

			if (!parentRule.raws.semicolon && parentRule.last === decl) {
				return;
			}

			const declString = decl.toString();

			checker.before({
				source: declString,
				index: declString.length,
				lineCheckStr: blockString(parentRule),
				err: (m) => {
					if (context.fix) {
						const value = decl.raws.value ? decl.raws.value.raw : decl.value;

						if (expectation.indexOf('always') === 0) {
							if (decl.important) {
								decl.raws.important = ' !important ';
							} else if (decl.raws.value) {
								decl.raws.value.raw = value.replace(/\s*$/, ' ');
							} else {
								decl.value = value.replace(/\s*$/, ' ');
							}

							return;
						} else if (expectation.indexOf('never') === 0) {
							if (decl.important) {
								decl.raws.important = decl.raws.important.replace(/\s*$/, '');
							} else if (decl.raws.value) {
								decl.raws.value.raw = value.replace(/\s*$/, '');
							} else {
								decl.value = value.replace(/\s*$/, '');
							}

							return;
						}
					}

					report({
						message: m,
						node: decl,
						index: decl.toString().length - 1,
						result,
						ruleName,
					});
				},
			});
		});
	};
};

rule.ruleName = ruleName;
rule.messages = messages;
module.exports = rule;

==> stylelint-13.2.0.tgz: package/lib/rules/declaration-block-semicolon-space-before/index.js <==
'use strict';

const blockString = require('../../utils/blockString');
const report = require('../../utils/report');
const ruleMessages = require('../../utils/ruleMessages');
const validateOptions = require('../../utils/validateOptions');
const whitespaceChecker = require('../../utils/whitespaceChecker');

const ruleName = 'declaration-block-semicolon-space-before';

const messages = ruleMessages(ruleName, {
	expectedBefore: () => 'Expected single space before ";"',
	rejectedBefore: () => 'Unexpected whitespace before ";"',
	expectedBeforeSingleLine: () =>
		'Expected single space before ";" in a single-line declaration block',
	rejectedBeforeSingleLine: () =>
		'Unexpected whitespace before ";" in a single-line declaration block',
});

function rule(expectation, options, context) {
	const checker = whitespaceChecker('space', expectation, messages);

	return (root, result) => {
		const validOptions = validateOptions(result, ruleName, {
			actual: expectation,
			possible: ['always', 'never', 'always-single-line', 'never-single-line'],
		});

		if (!validOptions) {
			return;
		}

		root.walkDecls((decl) => {
			// Ignore last declaration if there's no trailing semicolon
			const parentRule = decl.parent;

			if (!parentRule.raws.semicolon && parentRule.last === decl) {
				return;
			}

			const declString = decl.toString();

			checker.before({
				source: declString,
				index: declString.length,
				lineCheckStr: blockString(parentRule),
				err: (m) => {
					if (context.fix) {
						const value = decl.raws.value ? decl.raws.value.raw : decl.value;

						if (expectation.startsWith('always')) {
							if (decl.important) {
								decl.raws.important = ' !important ';
							} else if (decl.raws.value) {
								decl.raws.value.raw = value.replace(/\s*$/, ' ');
							} else {
								decl.value = value.replace(/\s*$/, ' ');
							}

							return;
						}

						if (expectation.startsWith('never')) {
							if (decl.important) {
								decl.raws.important = decl.raws.important.replace(/\s*$/, '');
							} else if (decl.raws.value) {
								decl.raws.value.raw = value.replace(/\s*$/, '');
							} else {
								decl.value = value.replace(/\s*$/, '');
							}

							return;
						}
					}

					report({
						message: m,
						node: decl,
						index: decl.toString().length - 1,
						result,
						ruleName,
					});
				},
			});
		});
	};
}

rule.ruleName = ruleName;
rule.messages = messages;
module.exports = rule;
